<?php

namespace App\Http\Controllers;

use App\Models\News;
use App\Models\VisitorInfo;
use Illuminate\Http\Request;

class AdminController extends Controller
{
    public function index()
    {
        $news = News::orderBy('created_at', 'desc')->get();
        return view('admin.index', compact('news'));
    }

    public function create()
    {
        return view('admin.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'title' => 'required|max:255',
            'content' => 'required',
            'image' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
        ]);

        $imagePath = null;
        if ($request->hasFile('image')) {
            $imagePath = $request->file('image')->store('news_images', 'public');
        }

        News::create([
            'title' => $request->title,
            'content' => $request->content,
            'image' => $imagePath,
            'published_at' => now(),
        ]);

        return redirect('/admin')->with('success', 'Notícia criada com sucesso!');
    }

    public function edit($id)
    {
        $news = News::findOrFail($id);
        return view('admin.edit', compact('news'));
    }

    public function update(Request $request, $id)
    {
        $request->validate([
            'title' => 'required|max:255',
            'content' => 'required',
            'image' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048'
        ]);

        $news = News::findOrFail($id);

        if ($request->hasFile('image')) {
            $imagePath = $request->file('image')->store('news_images', 'public');
            $news->image = $imagePath;
        }

        $news->title = $request->title;
        $news->content = $request->content;
        $news->save();

        return redirect('/admin')->with('success', 'Notícia atualizada com sucesso!');
    }

    public function destroy($id)
    {
        $news = News::findOrFail($id);
        $news->delete();

        return redirect('/admin')->with('success', 'Notícia removida com sucesso!');
    }

    public function reports()
    {
        $visitorInfos = VisitorInfo::orderBy('created_at', 'desc')->get();
        return view('admin.reports', compact('visitorInfos'));
    }
}
