<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\AdminController;
use App\Http\Controllers\NewsController;
use App\Http\Controllers\CommentController;
use App\Http\Controllers\LikeController;
use App\Http\Controllers\VisitorController;

// Rotas simples
Route::get('/', [NewsController::class, 'index'])->name('news.index');

// Rotas de recurso
Route::resource('news', NewsController::class);

// Rotas com parâmetros
Route::get('/user/{id}', function ($id) {
    return 'User ID: ' . $id;
});

// Rotas nomeadas
Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');

// Rotas com middleware
Route::middleware(['auth'])->group(function () {
    Route::get('/dashboard', function () {
        return view('dashboard');
    })->name('dashboard');

    Route::get('/settings', function () {
        return view('settings');
    })->name('settings');

    // Rotas de administração
    Route::get('/admin/create', [AdminController::class, 'create'])->name('admin.create');
    Route::post('/admin/store', [AdminController::class, 'store'])->name('admin.store');
    Route::get('/admin/index', [AdminController::class, 'index'])->name('admin.index');
    Route::get('/admin/edit/{id}', [AdminController::class, 'edit'])->name('admin.edit');
    Route::put('/admin/update/{id}', [AdminController::class, 'update'])->name('admin.update');
    Route::post('/admin/update/{id}', [AdminController::class, 'update'])->name('admin.update');
    Route::delete('/admin/destroy/{id}', [AdminController::class, 'destroy'])->name('admin.destroy');

    // Relatórios
    Route::get('/admin/reports', [AdminController::class, 'reports'])->name('admin.reports');

    // Rotas de likes e comentários
    Route::post('/news/{id}/like', [LikeController::class, 'store'])->name('likes.store');
    Route::delete('/news/{id}/like', [LikeController::class, 'destroy'])->name('likes.destroy');
    Route::post('/news/{id}/comments', [CommentController::class, 'store'])->name('comments.store');
});


// Requerendo as rotas de autenticação
require __DIR__ . '/auth.php';
